fhir_xpath_expression-class: An S4 class for xpath_expressions Objects of this class are...

fhir_xpath_expression-classR Documentation

An S4 class for xpath_expressions Objects of this class are essentially character vectors, but can only be valid XPath (1.0) expressions. They are mostly used in the fhir_columns class.

Description

An S4 class for xpath_expressions Objects of this class are essentially character vectors, but can only be valid XPath (1.0) expressions. They are mostly used in the fhir_columns class.


fhircrackr documentation built on June 4, 2026, 5:07 p.m.